﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Collections.Generic;
using System.Windows.Data;


namespace XamDataGridSample
{
    public class MainViewModel : INotifyPropertyChanged
    {
        public MainViewModel()
        {
            Patients = new CollectionView(patients = new ObservableCollection<string>());

            AddTestData();
            PropertyChanged += MainViewModel_PropertyChanged;
        }

        public CollectionView Patients { get; set; }

        public string NewPatient { get { return newPatient; } set { newPatient = value; OnPropertyChanged("NewPatient"); } }

        public void AddPatient()
        {
            if (!string.IsNullOrEmpty(NewPatient))
            {
                patients.Add(NewPatient);
                Patients.MoveCurrentToLast();
                NewPatient = string.Empty;
            }
        }

        private void MainViewModel_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            if (e.PropertyName == "NewPatient")
            {
                AddPatient();
            }
        }

        private void AddTestData()
        {
            patients.Add("ABC");
            patients.Add("PQR");
            patients.Add("LMN");
            patients.Add("XYZ");
            patients.Add("KLM");
        }

        private string newPatient;
        private ObservableCollection<string> patients;

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        public virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion
    }
}
